==> haskell-turtle-1.5.10-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.5.10
id: turtle-1.5.10-41u80qv3LvCDzkjZ8QUAo
key: turtle-1.5.10-41u80qv3LvCDzkjZ8QUAo
license: BSD-3-Clause
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
abi: 52ce2a86ab1b45cf74338514c7b14a27
exposed: True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/turtle-1.5.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/turtle-1.5.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/turtle-1.5.10
hs-libraries: HSturtle-1.5.10-41u80qv3LvCDzkjZ8QUAo
depends:
    base-4.11.1.0 ansi-wl-pprint-0.6.8.2-8f94dKGUwBPE80RGxGBXOm
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe bytestring-0.10.8.2
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs containers-0.5.11.0
    directory-1.3.1.5 exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    foldl-1.4.2-LAoiTPPFfoSOHzFw7aF5E
    hostname-1.0-Ej5hvtbOaDOEQosxQqfQV6
    managed-1.0.6-KscD4c3BFNIBs32klcB9iz process-1.6.3.0
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    system-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4 stm-2.4.5.0
    temporary-1.3-BKblIKMXPP7FnTvwIZQmdc text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU
    optional-args-1.0.2-F9yxtf9uFUtDRfwPkYMZFq
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ansi-wl-pprint-0.6.8.2-8f94dKGUwBPE80RGxGBXOm=cbc795f0a49989e87d7491265173e6cf
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=6b9ed802e71695075777b6e69687e9b7
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             foldl-1.4.2-LAoiTPPFfoSOHzFw7aF5E=14740de001e86b6afd4810c396ff7601
             hostname-1.0-Ej5hvtbOaDOEQosxQqfQV6=acbefd15b3ea2d6585ab61079033456e
             managed-1.0.6-KscD4c3BFNIBs32klcB9iz=e2311102e0f85c85a423aadf753f7f1e
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=03145435aceae6e5208d7a1b612976f3
             system-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4=1ae5b70c67f3a9f7f57b271f639a9849
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             temporary-1.3-BKblIKMXPP7FnTvwIZQmdc=5af137dad02e6ac7ebadd134a14e4d7c
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU=167699d54d61d2b1b6c082fc4a9ddc9b
             optional-args-1.0.2-F9yxtf9uFUtDRfwPkYMZFq=9ea26075a671cfbf8999eed24c229008
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.5.10-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.5.10
id: turtle-1.5.10-6xv6TKAEQJ4ECe6m7sQMoP
key: turtle-1.5.10-6xv6TKAEQJ4ECe6m7sQMoP
license: BSD-3-Clause
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
abi: d60f8920c177f7d2dd305678e246789f
exposed: True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/turtle-1.5.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/turtle-1.5.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/turtle-1.5.10
hs-libraries: HSturtle-1.5.10-6xv6TKAEQJ4ECe6m7sQMoP
depends:
    base-4.11.1.0 ansi-wl-pprint-0.6.8.2-8f94dKGUwBPE80RGxGBXOm
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe bytestring-0.10.8.2
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs containers-0.5.11.0
    directory-1.3.1.5 exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    foldl-1.4.2-JKCB0c8CjmDJOftHWJN073
    hostname-1.0-Ej5hvtbOaDOEQosxQqfQV6
    managed-1.0.6-KscD4c3BFNIBs32klcB9iz process-1.6.3.0
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    system-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4 stm-2.4.5.0
    temporary-1.3-BKblIKMXPP7FnTvwIZQmdc text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU
    optional-args-1.0.2-F9yxtf9uFUtDRfwPkYMZFq
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ansi-wl-pprint-0.6.8.2-8f94dKGUwBPE80RGxGBXOm=cbc795f0a49989e87d7491265173e6cf
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=6b9ed802e71695075777b6e69687e9b7
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             foldl-1.4.2-JKCB0c8CjmDJOftHWJN073=1247527a5d5507a1a9b950de7221b5fc
             hostname-1.0-Ej5hvtbOaDOEQosxQqfQV6=acbefd15b3ea2d6585ab61079033456e
             managed-1.0.6-KscD4c3BFNIBs32klcB9iz=e2311102e0f85c85a423aadf753f7f1e
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=03145435aceae6e5208d7a1b612976f3
             system-fileio-0.3.16.3-KZP3u31C9MzFt3sVRftkO4=1ae5b70c67f3a9f7f57b271f639a9849
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             temporary-1.3-BKblIKMXPP7FnTvwIZQmdc=5af137dad02e6ac7ebadd134a14e4d7c
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU=167699d54d61d2b1b6c082fc4a9ddc9b
             optional-args-1.0.2-F9yxtf9uFUtDRfwPkYMZFq=9ea26075a671cfbf8999eed24c229008
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
